bayespy.inference.vmp.nodes.stochastic.Stochastic.get_moments
=============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.stochastic

.. automethod:: Stochastic.get_moments